|logo|

**A full-featured, hackable tiling window manager written and configured in Python**

|website| |pypi| |travis| |rtd| |coveralls| |license|

Features
========

* Simple, small and extensible. It's easy to write your own layouts,
  widgets and commands.
* Configured in Python.
* Command shell that allows all aspects of Qtile to be managed and
  inspected.
* Complete remote scriptability - write scripts to set up workspaces,
  manipulate windows, update status bar widgets and more.
* Qtile's remote scriptability makes it one of the most thoroughly
  unit-tested window managers around.

Community
=========

Qtile is supported by a dedicated group of users. If you need any help, please
don't hesitate to fire off an email to our mailing list or join us on IRC.

:Mailing List: http://groups.google.com/group/qtile-dev
:IRC: irc://irc.oftc.net:6667/qtile

Contributing
============

Please report any suggestions, feature requests, bug reports, or annoyances to
the GitHub `issue tracker`_. There are also a few `tips & tricks`_,
and `guidelines`_ for contributing in the documentation.

.. _`issue tracker`: https://github.com/qtile/qtile/issues
.. _`tips & tricks`: http://docs.qtile.org/en/latest/manual/hacking.html
.. _`guidelines`: http://docs.qtile.org/en/latest/manual/contributing.html

.. |logo| image:: https://raw.githubusercontent.com/qtile/qtile/master/logo.png
    :alt: Logo
    :target: http://www.qtile.org
.. |website| image:: https://img.shields.io/badge/website-qtile.org-blue.svg
    :alt: Website
    :target: http://www.qtile.org
.. |pypi| image:: https://img.shields.io/pypi/v/qtile.svg
    :alt: PyPI
    :target: https://pypi.org/project/qtile/
.. |travis| image:: https://img.shields.io/travis/qtile/qtile.svg
    :alt: Travis
    :target: https://travis-ci.org/qtile/qtile
.. |rtd| image:: https://img.shields.io/readthedocs/qtile.svg
    :alt: Read the Docs
    :target: http://docs.qtile.org/en/latest/
.. |coveralls| image:: https://img.shields.io/coveralls/github/qtile/qtile/master.svg
    :alt: Coveralls
    :target: https://coveralls.io/github/qtile/qtile?branch=master
.. |license| image:: https://img.shields.io/github/license/qtile/qtile.svg
    :alt: License
    :target: https://github.com/qtile/qtile/blob/master/LICENSE
